cli

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2026 License: MIT Imports: 24 Imported by: 0

Documentation

Overview

Package cli provides the command-line interface for devsec.

Index

Constants

This section is empty.

Variables

var (
	Version   = "dev"
	GitCommit = "unknown"
	BuildDate = "unknown"
)

Version information set at build time.

var ErrPolicyViolation = errors.New("policy violation")

ErrPolicyViolation is returned when policy check fails.

var ErrSecretsFound = errors.New("secrets found")

ErrSecretsFound is returned when secrets are found during a scan.

var ErrVulnerabilitiesFound = errors.New("vulnerabilities found")

ErrVulnerabilitiesFound is returned when vulnerabilities are found during a scan.

Functions

func Execute

func Execute() error

Execute runs the root command.

func IsProgressEnabled

func IsProgressEnabled() bool

IsProgressEnabled returns true if the TUI progress dashboard should be shown.

func IsVerbose

func IsVerbose() bool

IsVerbose returns true if verbose output is enabled.

func NewAttestGenCmd

func NewAttestGenCmd() *cobra.Command

NewAttestGenCmd creates the attestation generate subcommand.

func NewAttestInspectCmd

func NewAttestInspectCmd() *cobra.Command

NewAttestInspectCmd creates the attestation inspect subcommand.

func NewAttestVerifyCmd

func NewAttestVerifyCmd() *cobra.Command

NewAttestVerifyCmd creates the attestation verify subcommand.

func NewAttestationCmd

func NewAttestationCmd() *cobra.Command

NewAttestationCmd creates the attestation command.

func NewComplianceAssessCmd

func NewComplianceAssessCmd() *cobra.Command

NewComplianceAssessCmd creates the compliance assess subcommand.

func NewComplianceCmd

func NewComplianceCmd() *cobra.Command

NewComplianceCmd creates the compliance command.

func NewComplianceControlsCmd

func NewComplianceControlsCmd() *cobra.Command

NewComplianceControlsCmd creates the compliance controls subcommand.

func NewComplianceControlsListCmd

func NewComplianceControlsListCmd() *cobra.Command

NewComplianceControlsListCmd creates the compliance controls list subcommand.

func NewComplianceCoverageCmd

func NewComplianceCoverageCmd() *cobra.Command

NewComplianceCoverageCmd creates the compliance coverage subcommand.

func NewComplianceGapsCmd

func NewComplianceGapsCmd() *cobra.Command

NewComplianceGapsCmd creates the compliance gaps subcommand.

func NewComplianceReportCmd

func NewComplianceReportCmd() *cobra.Command

NewComplianceReportCmd creates the compliance report subcommand.

func NewGenKeyCmd

func NewGenKeyCmd() *cobra.Command

NewGenKeyCmd creates the genkey subcommand.

func NewMLBiasCmd

func NewMLBiasCmd() *cobra.Command

NewMLBiasCmd creates the ml bias subcommand.

func NewMLCmd

func NewMLCmd() *cobra.Command

NewMLCmd creates the ml command.

func NewMLDetectCmd

func NewMLDetectCmd() *cobra.Command

NewMLDetectCmd creates the ml detect subcommand.

func NewMLDriftCmd

func NewMLDriftCmd() *cobra.Command

NewMLDriftCmd creates the ml drift subcommand.

func NewMLFairnessCmd

func NewMLFairnessCmd() *cobra.Command

NewMLFairnessCmd creates the ml fairness subcommand.

func NewMLModelCardCmd

func NewMLModelCardCmd() *cobra.Command

NewMLModelCardCmd creates the ml model-card subcommand.

func NewMLValidateCmd

func NewMLValidateCmd() *cobra.Command

NewMLValidateCmd creates the ml validate subcommand.

func NewPipelineCmd

func NewPipelineCmd() *cobra.Command

NewPipelineCmd creates the pipeline command.

func NewPipelineGenerateCmd

func NewPipelineGenerateCmd() *cobra.Command

NewPipelineGenerateCmd creates the pipeline generate subcommand.

func NewPipelineRunCmd

func NewPipelineRunCmd() *cobra.Command

NewPipelineRunCmd creates the pipeline run subcommand.

func NewPipelineValidateCmd

func NewPipelineValidateCmd() *cobra.Command

NewPipelineValidateCmd creates the pipeline validate subcommand.

func NewPolicyCheckCmd

func NewPolicyCheckCmd() *cobra.Command

NewPolicyCheckCmd creates the policy check subcommand.

func NewPolicyCmd

func NewPolicyCmd() *cobra.Command

NewPolicyCmd creates the policy command.

func NewPolicyDocsCmd

func NewPolicyDocsCmd() *cobra.Command

NewPolicyDocsCmd creates the policy docs subcommand.

func NewPolicyValidateCmd

func NewPolicyValidateCmd() *cobra.Command

NewPolicyValidateCmd creates the policy validate subcommand.

func NewRootCmd

func NewRootCmd() *cobra.Command

NewRootCmd creates the root command for devsec CLI.

func NewSBOMCmd

func NewSBOMCmd() *cobra.Command

NewSBOMCmd creates the sbom command.

func NewScanCmd

func NewScanCmd() *cobra.Command

NewScanCmd creates the scan command.

func NewScanDependenciesCmd

func NewScanDependenciesCmd() *cobra.Command

NewScanDependenciesCmd creates the scan dependencies subcommand.

func NewScanSastCmd

func NewScanSastCmd() *cobra.Command

NewScanSastCmd creates the scan sast subcommand.

func NewScanSecretsCmd

func NewScanSecretsCmd() *cobra.Command

NewScanSecretsCmd creates the scan secrets subcommand.

func NewScanVulnerabilitiesCmd

func NewScanVulnerabilitiesCmd() *cobra.Command

NewScanVulnerabilitiesCmd creates the scan vulnerabilities subcommand.

func NewSignArtifactCmd

func NewSignArtifactCmd() *cobra.Command

NewSignArtifactCmd creates the sign artifact subcommand.

func NewSignCmd

func NewSignCmd() *cobra.Command

NewSignCmd creates the sign command.

func NewVerifyCmd

func NewVerifyCmd() *cobra.Command

NewVerifyCmd creates the verify subcommand.

func NewVersionCmd

func NewVersionCmd() *cobra.Command

NewVersionCmd creates the version command.

Types

type Scanner

type Scanner interface {
	Scan(ctx context.Context, path string) ([]model.Finding, error)
	Close(ctx context.Context) error
}

Scanner is an interface for security scanners.

Jump to