Documentation
¶
Overview ¶
Package cli provides the command-line interface for devsec.
Index ¶
- Variables
- func Execute() error
- func IsProgressEnabled() bool
- func IsVerbose() bool
- func NewAttestGenCmd() *cobra.Command
- func NewAttestInspectCmd() *cobra.Command
- func NewAttestVerifyCmd() *cobra.Command
- func NewAttestationCmd() *cobra.Command
- func NewComplianceAssessCmd() *cobra.Command
- func NewComplianceCmd() *cobra.Command
- func NewComplianceControlsCmd() *cobra.Command
- func NewComplianceControlsListCmd() *cobra.Command
- func NewComplianceCoverageCmd() *cobra.Command
- func NewComplianceGapsCmd() *cobra.Command
- func NewComplianceReportCmd() *cobra.Command
- func NewGenKeyCmd() *cobra.Command
- func NewMLBiasCmd() *cobra.Command
- func NewMLCmd() *cobra.Command
- func NewMLDetectCmd() *cobra.Command
- func NewMLDriftCmd() *cobra.Command
- func NewMLFairnessCmd() *cobra.Command
- func NewMLModelCardCmd() *cobra.Command
- func NewMLValidateCmd() *cobra.Command
- func NewPipelineCmd() *cobra.Command
- func NewPipelineGenerateCmd() *cobra.Command
- func NewPipelineRunCmd() *cobra.Command
- func NewPipelineValidateCmd() *cobra.Command
- func NewPolicyCheckCmd() *cobra.Command
- func NewPolicyCmd() *cobra.Command
- func NewPolicyDocsCmd() *cobra.Command
- func NewPolicyValidateCmd() *cobra.Command
- func NewRootCmd() *cobra.Command
- func NewSBOMCmd() *cobra.Command
- func NewScanCmd() *cobra.Command
- func NewScanDependenciesCmd() *cobra.Command
- func NewScanSastCmd() *cobra.Command
- func NewScanSecretsCmd() *cobra.Command
- func NewScanVulnerabilitiesCmd() *cobra.Command
- func NewSignArtifactCmd() *cobra.Command
- func NewSignCmd() *cobra.Command
- func NewVerifyCmd() *cobra.Command
- func NewVersionCmd() *cobra.Command
- type Scanner
Constants ¶
This section is empty.
Variables ¶
var ( Version = "dev" GitCommit = "unknown" BuildDate = "unknown" )
Version information set at build time.
var ErrPolicyViolation = errors.New("policy violation")
ErrPolicyViolation is returned when policy check fails.
var ErrSecretsFound = errors.New("secrets found")
ErrSecretsFound is returned when secrets are found during a scan.
var ErrVulnerabilitiesFound = errors.New("vulnerabilities found")
ErrVulnerabilitiesFound is returned when vulnerabilities are found during a scan.
Functions ¶
func IsProgressEnabled ¶
func IsProgressEnabled() bool
IsProgressEnabled returns true if the TUI progress dashboard should be shown.
func NewAttestGenCmd ¶
NewAttestGenCmd creates the attestation generate subcommand.
func NewAttestInspectCmd ¶
NewAttestInspectCmd creates the attestation inspect subcommand.
func NewAttestVerifyCmd ¶
NewAttestVerifyCmd creates the attestation verify subcommand.
func NewAttestationCmd ¶
NewAttestationCmd creates the attestation command.
func NewComplianceAssessCmd ¶
NewComplianceAssessCmd creates the compliance assess subcommand.
func NewComplianceCmd ¶
NewComplianceCmd creates the compliance command.
func NewComplianceControlsCmd ¶
NewComplianceControlsCmd creates the compliance controls subcommand.
func NewComplianceControlsListCmd ¶
NewComplianceControlsListCmd creates the compliance controls list subcommand.
func NewComplianceCoverageCmd ¶
NewComplianceCoverageCmd creates the compliance coverage subcommand.
func NewComplianceGapsCmd ¶
NewComplianceGapsCmd creates the compliance gaps subcommand.
func NewComplianceReportCmd ¶
NewComplianceReportCmd creates the compliance report subcommand.
func NewMLDetectCmd ¶
NewMLDetectCmd creates the ml detect subcommand.
func NewMLDriftCmd ¶
NewMLDriftCmd creates the ml drift subcommand.
func NewMLFairnessCmd ¶
NewMLFairnessCmd creates the ml fairness subcommand.
func NewMLModelCardCmd ¶
NewMLModelCardCmd creates the ml model-card subcommand.
func NewMLValidateCmd ¶
NewMLValidateCmd creates the ml validate subcommand.
func NewPipelineCmd ¶
NewPipelineCmd creates the pipeline command.
func NewPipelineGenerateCmd ¶
NewPipelineGenerateCmd creates the pipeline generate subcommand.
func NewPipelineRunCmd ¶
NewPipelineRunCmd creates the pipeline run subcommand.
func NewPipelineValidateCmd ¶
NewPipelineValidateCmd creates the pipeline validate subcommand.
func NewPolicyCheckCmd ¶
NewPolicyCheckCmd creates the policy check subcommand.
func NewPolicyDocsCmd ¶
NewPolicyDocsCmd creates the policy docs subcommand.
func NewPolicyValidateCmd ¶
NewPolicyValidateCmd creates the policy validate subcommand.
func NewRootCmd ¶
NewRootCmd creates the root command for devsec CLI.
func NewScanDependenciesCmd ¶
NewScanDependenciesCmd creates the scan dependencies subcommand.
func NewScanSastCmd ¶
NewScanSastCmd creates the scan sast subcommand.
func NewScanSecretsCmd ¶
NewScanSecretsCmd creates the scan secrets subcommand.
func NewScanVulnerabilitiesCmd ¶
NewScanVulnerabilitiesCmd creates the scan vulnerabilities subcommand.
func NewSignArtifactCmd ¶
NewSignArtifactCmd creates the sign artifact subcommand.