Documentation
¶
Overview ¶
Package model defines core types used throughout the devsec application.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Finding ¶
type Finding struct {
ID string `json:"id"`
Title string `json:"title"`
Description string `json:"description"`
Rule string `json:"rule"`
Scanner string `json:"scanner"`
Severity Severity `json:"severity"`
Location Location `json:"location"`
}
Finding represents a single security or compliance finding. Fields ordered for optimal memory alignment.
type Location ¶
type Location struct {
File string `json:"file"`
StartLine int `json:"start_line"`
EndLine int `json:"end_line"`
Column int `json:"column,omitempty"`
}
Location represents the location of a finding in source code.
type Report ¶
type Report struct {
Metadata map[string]string `json:"metadata"`
Timestamp string `json:"timestamp"`
Findings []Finding `json:"findings"`
Summary Summary `json:"summary"`
}
Report represents an aggregated report from multiple scanners. Fields ordered for optimal memory alignment.
type Severity ¶
type Severity string
Severity represents the severity level of a finding.
const ( // SeverityCritical represents critical severity findings. SeverityCritical Severity = "critical" // SeverityHigh represents high severity findings. SeverityHigh Severity = "high" // SeverityMedium represents medium severity findings. SeverityMedium Severity = "medium" // SeverityLow represents low severity findings. SeverityLow Severity = "low" // SeverityInfo represents informational findings. SeverityInfo Severity = "info" )
Click to show internal directories.
Click to hide internal directories.